==> cloudformation-1.104.0-sources.jar: software/amazon/awscdk/services/cloudformation/CfnModuleVersionProps.java <==
package software.amazon.awscdk.services.cloudformation;

/**
 * Properties for defining a `AWS::CloudFormation::ModuleVersion`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.29.0 (build 41df200)", date = "2021-05-14T22:40:08.312Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudformation.$Module.class, fqn = "@aws-cdk/aws-cloudformation.CfnModuleVersionProps")
@software.amazon.jsii.Jsii.Proxy(CfnModuleVersionProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnModuleVersionProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::CloudFormation::ModuleVersion.ModuleName`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getModuleName();

    /**
     * `AWS::CloudFormation::ModuleVersion.ModulePackage`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getModulePackage();

    /**
     * @return a {@link Builder} of {@link CfnModuleVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnModuleVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnModuleVersionProps> {
        private java.lang.String moduleName;
        private java.lang.String modulePackage;

        /**
         * Sets the value of {@link CfnModuleVersionProps#getModuleName}
         * @param moduleName `AWS::CloudFormation::ModuleVersion.ModuleName`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder moduleName(java.lang.String moduleName) {
            this.moduleName = moduleName;
            return this;
        }

        /**
         * Sets the value of {@link CfnModuleVersionProps#getModulePackage}
         * @param modulePackage `AWS::CloudFormation::ModuleVersion.ModulePackage`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder modulePackage(java.lang.String modulePackage) {
            this.modulePackage = modulePackage;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnModuleVersionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnModuleVersionProps build() {
            return new Jsii$Proxy(moduleName, modulePackage);
        }
    }

    /**
     * An implementation for {@link CfnModuleVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnModuleVersionProps {
        private final java.lang.String moduleName;
        private final java.lang.String modulePackage;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.moduleName = software.amazon.jsii.Kernel.get(this, "moduleName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.modulePackage = software.amazon.jsii.Kernel.get(this, "modulePackage", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String moduleName, final java.lang.String modulePackage) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.moduleName = java.util.Objects.requireNonNull(moduleName, "moduleName is required");
            this.modulePackage = java.util.Objects.requireNonNull(modulePackage, "modulePackage is required");
        }

        @Override
        public final java.lang.String getModuleName() {
            return this.moduleName;
        }

        @Override
        public final java.lang.String getModulePackage() {
            return this.modulePackage;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("moduleName", om.valueToTree(this.getModuleName()));
            data.set("modulePackage", om.valueToTree(this.getModulePackage()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cloudformation.CfnModuleVersionProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnModuleVersionProps.Jsii$Proxy that = (CfnModuleVersionProps.Jsii$Proxy) o;

            if (!moduleName.equals(that.moduleName)) return false;
            return this.modulePackage.equals(that.modulePackage);
        }

        @Override
        public final int hashCode() {
            int result = this.moduleName.hashCode();
            result = 31 * result + (this.modulePackage.hashCode());
            return result;
        }
    }
}

==> cloudformation-1.173.0-sources.jar: software/amazon/awscdk/services/cloudformation/CfnModuleVersionProps.java <==
package software.amazon.awscdk.services.cloudformation;

/**
 * Properties for defining a `CfnModuleVersion`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.cloudformation.*;
 * CfnModuleVersionProps cfnModuleVersionProps = CfnModuleVersionProps.builder()
 *         .moduleName("moduleName")
 *         .modulePackage("modulePackage")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-16T18:50:30.713Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudformation.$Module.class, fqn = "@aws-cdk/aws-cloudformation.CfnModuleVersionProps")
@software.amazon.jsii.Jsii.Proxy(CfnModuleVersionProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnModuleVersionProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The name of the module being registered.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getModuleName();

    /**
     * A URL to the S3 bucket containing the package that contains the template fragment and schema files for the module version to register.
     * <p>
     * <blockquote>
     * <p>
     * The user registering the module version must be able to access the module package in the S3 bucket. That's, the user needs to have <a href="https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html">GetObject</a> permissions for the package. For more information, see <a href="https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazons3.html">Actions, Resources, and Condition Keys for Amazon S3</a> in the <em>AWS Identity and Access Management User Guide</em> .
     * <p>
     * </blockquote>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getModulePackage();

    /**
     * @return a {@link Builder} of {@link CfnModuleVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnModuleVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnModuleVersionProps> {
        java.lang.String moduleName;
        java.lang.String modulePackage;

        /**
         * Sets the value of {@link CfnModuleVersionProps#getModuleName}
         * @param moduleName The name of the module being registered. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder moduleName(java.lang.String moduleName) {
            this.moduleName = moduleName;
            return this;
        }

        /**
         * Sets the value of {@link CfnModuleVersionProps#getModulePackage}
         * @param modulePackage A URL to the S3 bucket containing the package that contains the template fragment and schema files for the module version to register. This parameter is required.
         *                      <blockquote>
         *                      <p>
         *                      The user registering the module version must be able to access the module package in the S3 bucket. That's, the user needs to have <a href="https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html">GetObject</a> permissions for the package. For more information, see <a href="https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazons3.html">Actions, Resources, and Condition Keys for Amazon S3</a> in the <em>AWS Identity and Access Management User Guide</em> .
         *                      <p>
         *                      </blockquote>
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder modulePackage(java.lang.String modulePackage) {
            this.modulePackage = modulePackage;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnModuleVersionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnModuleVersionProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnModuleVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnModuleVersionProps {
        private final java.lang.String moduleName;
        private final java.lang.String modulePackage;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.moduleName = software.amazon.jsii.Kernel.get(this, "moduleName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.modulePackage = software.amazon.jsii.Kernel.get(this, "modulePackage", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.moduleName = java.util.Objects.requireNonNull(builder.moduleName, "moduleName is required");
            this.modulePackage = java.util.Objects.requireNonNull(builder.modulePackage, "modulePackage is required");
        }

        @Override
        public final java.lang.String getModuleName() {
            return this.moduleName;
        }

        @Override
        public final java.lang.String getModulePackage() {
            return this.modulePackage;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("moduleName", om.valueToTree(this.getModuleName()));
            data.set("modulePackage", om.valueToTree(this.getModulePackage()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cloudformation.CfnModuleVersionProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnModuleVersionProps.Jsii$Proxy that = (CfnModuleVersionProps.Jsii$Proxy) o;

            if (!moduleName.equals(that.moduleName)) return false;
            return this.modulePackage.equals(that.modulePackage);
        }

        @Override
        public final int hashCode() {
            int result = this.moduleName.hashCode();
            result = 31 * result + (this.modulePackage.hashCode());
            return result;
        }
    }
}
